#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.trigger_dagrun import TriggerDagRunOperator
from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_crm_tags', default_args=default_args,
schedule_interval="0 0-23/1 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="crm_tags_failed",
    html_content='<h3>您好，crm_tags作业失败，请及时处理" </h3>')

huiju_tags_feign = SSHOperator(
ssh_hook=sshHook,
task_id='huiju_tags_feign',
command='python3 /data/airflow/etl/API/huiju_tags_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

huiju_tags_load = SSHOperator(
ssh_hook=sshHook,
task_id='huiju_tags_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"huiju_tags_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

huiju_tags_feign >> huiju_tags_load


uds_crm_tag_update = SSHOperator(
ssh_hook=sshHook,
task_id='uds_crm_tag_update',
command='python /data/airflow/etl/Python/crm_tag_update.py',
params={'my_param':"uds_crm_tag_update"},
depends_on_past=False, 
retries=3, 
dag=dag)

scrm_tags_5000 = SSHOperator(
ssh_hook=sshHook,
task_id='scrm_tags_5000',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_scrm_tags"},
depends_on_past=False, 
retries=3, 
dag=dag)

huiju_tags_load >> scrm_tags_5000
# scrm_tags_5000 >> task_failed 

scrm_tags_5000 >> uds_crm_tag_update
uds_crm_tag_update >> task_failed 
