#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.trigger_dagrun import TriggerDagRunOperator
from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_ser_main', default_args=default_args,
schedule_interval="0 0 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="ser_main_failed",
    html_content='<h3>您好，ser_main作业失败，请及时处理" </h3>')


uds_maintain_data_file = SSHOperator(
ssh_hook=sshHook,
task_id='uds_maintain_data_file',
command='python /data/airflow/etl/CTL/maintain_data_file.py /data/datafile',
params={'my_param':"uds_maintain_data_file"},
depends_on_past=False, 
retries=3, 
dag=dag)


uds_maintain_logs = SSHOperator(
ssh_hook=sshHook,
task_id='uds_maintain_logs',
command='python /data/airflow/etl/CTL/maintain_logs.py ',
params={'my_param':"uds_maintain_logs"},
depends_on_past=False, 
retries=3, 
dag=dag)

uds_maintain_data_file >> uds_maintain_logs
uds_maintain_logs >> task_failed 
