#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.trigger_dagrun import TriggerDagRunOperator
from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_smart_ccc_cdr', default_args=default_args,
schedule_interval="0 0-23/1 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="smart_ccc_cdr_failed",
    html_content='<h3>您好，smart_ccc_cdr作业失败，请及时处理" </h3>')

cc_cdr_ib_list_feign = SSHOperator(
ssh_hook=sshHook,
task_id='cc_cdr_ib_list_feign',
command='python3 /data/airflow/etl/API/cc_cdr_ib_list_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

cc_cdr_ib_list_load = SSHOperator(
ssh_hook=sshHook,
task_id='cc_cdr_ib_list_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"cc_cdr_ib_list_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

cc_cdr_ib_list_feign >> cc_cdr_ib_list_load

cc_cdr_ob_list_feign = SSHOperator(
ssh_hook=sshHook,
task_id='cc_cdr_ob_list_feign',
command='python3 /data/airflow/etl/API/cc_cdr_ob_list_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

cc_cdr_ob_list_load = SSHOperator(
ssh_hook=sshHook,
task_id='cc_cdr_ob_list_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"cc_cdr_ob_list_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

cc_cdr_ob_list_feign >> cc_cdr_ob_list_load

cc_cdr_ib_agent_list_feign = SSHOperator(
ssh_hook=sshHook,
task_id='cc_cdr_ib_agent_list_feign',
command='python3 /data/airflow/etl/API/cc_cdr_ib_agent_list_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

cc_cdr_ib_agent_list_load = SSHOperator(
ssh_hook=sshHook,
task_id='cc_cdr_ib_agent_list_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"cc_cdr_ib_agent_list_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

cc_cdr_ib_agent_list_feign >> cc_cdr_ib_agent_list_load

tr_cc_cdr_ib_agent_list_9092 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_cc_cdr_ib_agent_list_9092',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_cc_cdr_ib_agent_list"},
depends_on_past=False, 
retries=3, 
dag=dag)

tr_cc_cdr_ib_list_9521 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_cc_cdr_ib_list_9521',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_cc_cdr_ib_list"},
depends_on_past=False, 
retries=3, 
dag=dag)

tr_cc_cdr_ob_detail_5097 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_cc_cdr_ob_detail_5097',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_cc_cdr_ob_detail"},
depends_on_past=False, 
retries=3, 
dag=dag)

tr_cc_cdr_ob_list_4070 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_cc_cdr_ob_list_4070',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_cc_cdr_ob_list"},
depends_on_past=False, 
retries=3, 
dag=dag)

t01_ccc_ib_record = SSHOperator(
ssh_hook=sshHook,
task_id='t01_ccc_ib_record',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_ccc_ib_record_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
t01_ccc_ob_record = SSHOperator(
ssh_hook=sshHook,
task_id='t01_ccc_ob_record',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_ccc_ob_record_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cust_call_ccc_record = SSHOperator(
ssh_hook=sshHook,
task_id='cust_call_ccc_record',
command='/data/airflow/etl/COM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"cust_call_ccc_record_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cc_cdr_ib_agent_list_load >> tr_cc_cdr_ib_agent_list_9092
cc_cdr_ib_list_load >> tr_cc_cdr_ib_list_9521
cc_cdr_ob_list_load >> tr_cc_cdr_ob_list_4070
cc_cdr_ob_list_load >> tr_cc_cdr_ob_detail_5097
tr_cc_cdr_ib_list_9521 >> t01_ccc_ib_record
tr_cc_cdr_ib_agent_list_9092 >> t01_ccc_ib_record
tr_cc_cdr_ob_list_4070 >> t01_ccc_ob_record
tr_cc_cdr_ob_detail_5097 >> t01_ccc_ob_record
t01_ccc_ib_record >> cust_call_ccc_record
t01_ccc_ob_record >> cust_call_ccc_record
cust_call_ccc_record >> task_failed 
