/***************************************************************************************************/
/*script in Sql, generate by SdmCreateScript 2020(by Qihang Feng, QF255001@TERADATA.COM)     */
/*VERSION 01.10 revised on 2020-08-25                                                              */
/*Brilliance stems from wisdoms.                                                                   */
/*************Head Section**************************************************************************/
/*Script Use: Periodically load data to :t01_ccc_chat_message_detail(smartccc会话消息详情)             */
/*Create Date:2024-07-19 15:52:26                                                                  */
/*SDM Developed By: dev                                                                            */
/*SDM Developed Date: 2024-07-19                                                                   */
/*SDM Checked By: dev                                                                              */
/*SDM Checked Date: 2024-07-19                                                                     */
/*Script Developed By: dev                                                                         */
/*Script Checked By: dev                                                                           */
/*Source table 1: p10_sa.s98_s_tr_chat_messages                                                    */
/*Job Type: Inbound transform (Tier 1 to Tier 2)                                                   */
/*Target Table:t01_ccc_chat_message_detail                                                         */
/*ETL Job Name:t01_ccc_chat_message_detail                                                         */
/*ETL Frequency:Daily                                                                              */
/*ETL Policy:F2                                                                                    */
/********************************************************************************************/
/*******Main Section**************************************************************************/
\set ON_ERROR_STOP on
\set AUTOCOMMIT on
\timing on



/*创建临时表加载当前数据                                                                           */
CREATE TEMPORARY TABLE t01_ccc_chat_message_detail_agi_CUR_I 
 ( LIKE :PDMDB.t01_ccc_chat_message_detail)
ON COMMIT PRESERVE ROWS;



/*创建临时表加载不同数据                                                                           */
CREATE TEMPORARY TABLE t01_ccc_chat_message_detail_agi_INS 
( LIKE :PDMDB.t01_ccc_chat_message_detail)
ON COMMIT PRESERVE ROWS;

            
/*****************************************************************************************************/
/* GROUP 1:Source Table:s98_s_tr_chat_messages********************************************************/
/*****************************************************************************************************/
INSERT INTO t01_ccc_chat_message_detail_agi_CUR_I (
            message_unique_id                       /* 消息编号*/
           ,chat_unique_id                          /*在线客服会话ID*/
           ,sender_id                               /*消息发送方ID*/
           ,sender_name                             /*消息发送方名称*/
           ,sender_type                             /*消息发送方类型*/
           ,message_type                            /*消息类型*/
           ,content                                 /*消息内容*/
           ,file_address                            /*文件的地址*/
           ,file_name                               /*文件名称*/
           ,file_url                                /*文件访问路径*/
           ,send_status                             /*消息发送状态*/
           ,sensitive_word                          /*敏感词*/
           ,create_time                             /*消息创建时间戳*/
           ,Etl_Batch_No                            /*作业批次号*/
           ,Etl_First_Dt                            /*最初入库时间*/
           ,Etl_Job                                 /*作业名称*/
           ,Etl_Proc_Dt                             /*本次入库时间*/
           ,Etl_Tx_Dt                               /*作业运行时间*/
           ,Src_Sysname                             /*来源系统*/
           ,Src_Table                               /*来源表*/
        )
SELECT
         COALESCE(TRIM(CAST(p0.unique_id AS varchar(50))),'')        /*message_unique_id*/
        ,COALESCE(TRIM(CAST(p0.main_unique_id AS varchar(50))),'')        /*chat_unique_id*/
        ,COALESCE(TRIM(CAST(p0.sender_id AS varchar(50))),'')        /*sender_id*/
        ,COALESCE(TRIM(CAST(p0.sender_name AS varchar(50))),'')        /*sender_name*/
        ,COALESCE(TRIM(CAST(p0.sender_type AS varchar(10))),'')        /*sender_type*/
        ,COALESCE(TRIM(CAST(p0.message_type AS varchar(10))),'')        /*message_type*/
        ,COALESCE(TRIM(p0.content),'')                             /*content*/
        ,COALESCE(TRIM(p0.file_key),'')                            /*file_address*/
        ,COALESCE(TRIM(CAST(p0.file_name AS varchar(100))),'')        /*file_name*/
        ,COALESCE(TRIM(p0.file_url),'')                            /*file_url*/
        ,COALESCE(TRIM(CAST(p0.send_status AS varchar(10))),'')        /*send_status*/
        ,COALESCE(TRIM(p0.sensitive_word),'')                      /*sensitive_word*/
        ,to_timestamp(p0.create_time::bigint/1000)::timestamp(0)        /*create_time*/
        ,0                                                         /*Etl_Batch_No*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_First_Dt*/
        ,:ETLJOB                                                   /*Etl_Job*/
        ,current_timestamp(0)                                      /*Etl_Proc_Dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_Tx_Dt*/
        ,Substr('s98_s_tr_chat_messages',1,3)                      /*Src_Sysname*/
        ,'s98_s_tr_chat_messages'                                  /*Src_Table*/
        
FROM p10_sa.s98_s_tr_chat_messages  p0
;



/*将不同数据插入到临时表                                                                           */
;INSERT INTO t01_ccc_chat_message_detail_agi_INS (
         chat_unique_id                                            /*在线客服会话ID*/
        ,sender_id                                                 /*消息发送方ID*/
        ,sender_name                                               /*消息发送方名称*/
        ,sender_type                                               /*消息发送方类型*/
        ,message_type                                              /*消息类型*/
        ,content                                                   /*消息内容*/
        ,file_address                                              /*文件的地址*/
        ,file_name                                                 /*文件名称*/
        ,file_url                                                  /*文件访问路径*/
        ,send_status                                               /*消息发送状态*/
        ,sensitive_word                                            /*敏感词*/
        ,create_time                                               /*消息创建时间戳*/
        ,message_unique_id                                         /* 消息编号*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
    SELECT
         P1.chat_unique_id                                            /*在线客服会话ID*/
        ,P1.sender_id                                                 /*消息发送方ID*/
        ,P1.sender_name                                               /*消息发送方名称*/
        ,P1.sender_type                                               /*消息发送方类型*/
        ,P1.message_type                                              /*消息类型*/
        ,P1.content                                                   /*消息内容*/
        ,P1.file_address                                              /*文件的地址*/
        ,P1.file_name                                                 /*文件名称*/
        ,P1.file_url                                                  /*文件访问路径*/
        ,P1.send_status                                               /*消息发送状态*/
        ,P1.sensitive_word                                            /*敏感词*/
        ,P1.create_time                                               /*消息创建时间戳*/
        ,P1.message_unique_id                                         /* 消息编号*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM t01_ccc_chat_message_detail_agi_CUR_I P1
LEFT JOIN :PDMDB.t01_ccc_chat_message_detail P2
ON    P1.chat_unique_id = P2.chat_unique_id
    AND P1.sender_id = P2.sender_id
    AND P1.sender_name = P2.sender_name
    AND P1.sender_type = P2.sender_type
    AND P1.message_type = P2.message_type
    AND P1.content = P2.content
    AND P1.file_address = P2.file_address
    AND P1.file_name = P2.file_name
    AND P1.file_url = P2.file_url
    AND P1.send_status = P2.send_status
    AND P1.sensitive_word = P2.sensitive_word
    AND P1.create_time = P2.create_time
    AND P1.message_unique_id = P2.message_unique_id
    
WHERE  P2.chat_unique_id IS NULL
    OR P2.sender_id IS NULL
    OR P2.sender_name IS NULL
    OR P2.sender_type IS NULL
    OR P2.message_type IS NULL
    OR P2.content IS NULL
    OR P2.file_address IS NULL
    OR P2.file_name IS NULL
    OR P2.file_url IS NULL
    OR P2.send_status IS NULL
    OR P2.sensitive_word IS NULL
    OR P2.create_time IS NULL
    OR P2.message_unique_id IS NULL
    
; 
/*将新增数据插入到目标表                                                                           */
;INSERT INTO :PDMDB.t01_ccc_chat_message_detail (
         chat_unique_id                                            /*在线客服会话ID*/
        ,sender_id                                                 /*消息发送方ID*/
        ,sender_name                                               /*消息发送方名称*/
        ,sender_type                                               /*消息发送方类型*/
        ,message_type                                              /*消息类型*/
        ,content                                                   /*消息内容*/
        ,file_address                                              /*文件的地址*/
        ,file_name                                                 /*文件名称*/
        ,file_url                                                  /*文件访问路径*/
        ,send_status                                               /*消息发送状态*/
        ,sensitive_word                                            /*敏感词*/
        ,create_time                                               /*消息创建时间戳*/
        ,message_unique_id                                         /* 消息编号*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
SELECT
         P1.chat_unique_id                                            /*在线客服会话ID*/
        ,P1.sender_id                                                 /*消息发送方ID*/
        ,P1.sender_name                                               /*消息发送方名称*/
        ,P1.sender_type                                               /*消息发送方类型*/
        ,P1.message_type                                              /*消息类型*/
        ,P1.content                                                   /*消息内容*/
        ,P1.file_address                                              /*文件的地址*/
        ,P1.file_name                                                 /*文件名称*/
        ,P1.file_url                                                  /*文件访问路径*/
        ,P1.send_status                                               /*消息发送状态*/
        ,P1.sensitive_word                                            /*敏感词*/
        ,P1.create_time                                               /*消息创建时间戳*/
        ,P1.message_unique_id                                         /* 消息编号*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM t01_ccc_chat_message_detail_agi_INS P1
ON CONFLICT ( message_unique_id)
DO UPDATE SET
     message_unique_id=excluded.message_unique_id
    ,chat_unique_id=excluded.chat_unique_id
    ,sender_id=excluded.sender_id
    ,sender_name=excluded.sender_name
    ,sender_type=excluded.sender_type
    ,message_type=excluded.message_type
    ,content=excluded.content
    ,file_address=excluded.file_address
    ,file_name=excluded.file_name
    ,file_url=excluded.file_url
    ,send_status=excluded.send_status
    ,sensitive_word=excluded.sensitive_word
    ,create_time=excluded.create_time
    ,Etl_Batch_No=excluded.Etl_Batch_No
    ,Etl_First_Dt=excluded.Etl_First_Dt
    ,Etl_Job=excluded.Etl_Job
    ,Etl_Proc_Dt=excluded.Etl_Proc_Dt
    ,Etl_Tx_Dt=excluded.Etl_Tx_Dt
    ,Src_Sysname=excluded.Src_Sysname
    ,Src_Table=excluded.Src_Table
    

;
/*****程序结束退出                                               */
\q

