/***************************************************************************************************/
/*script in Sql, generate by SdmCreateScript 2020(by Qihang Feng, QF255001@TERADATA.COM)     */
/*VERSION 01.10 revised on 2020-08-25                                                              */
/*Brilliance stems from wisdoms.                                                                   */
/*************Head Section**************************************************************************/
/*Script Use: Periodically load data to :t01_scrm_label(SCRM标签信息)             */
/*Create Date:2024-07-11 18:22:36                                                                  */
/*SDM Developed By: dev                                                                            */
/*SDM Developed Date: 2024-07-11                                                                   */
/*SDM Checked By: dev                                                                              */
/*SDM Checked Date: 2024-07-11                                                                     */
/*Script Developed By: dev                                                                         */
/*Script Checked By: dev                                                                           */
/*Source table 1: p10_sa.s98_s_scrm_tags                                                           */
/*Job Type: Inbound transform (Tier 1 to Tier 2)                                                   */
/*Target Table:t01_scrm_label                                                                      */
/*ETL Job Name:t01_scrm_label                                                                      */
/*ETL Frequency:Daily                                                                              */
/*ETL Policy:F2                                                                                    */
/********************************************************************************************/
/*******Main Section**************************************************************************/
\set ON_ERROR_STOP on
\set AUTOCOMMIT on
\timing on



/*创建临时表加载当前数据                                                                           */
CREATE TEMPORARY TABLE t01_scrm_label_agi_CUR_I 
 ( LIKE :PDMDB.t01_scrm_label)
ON COMMIT PRESERVE ROWS;



/*创建临时表加载不同数据                                                                           */
CREATE TEMPORARY TABLE t01_scrm_label_agi_INS 
( LIKE :PDMDB.t01_scrm_label)
ON COMMIT PRESERVE ROWS;

            
/*****************************************************************************************************/
/* GROUP 1:Source Table:s98_s_scrm_tags***************************************************************/
/*****************************************************************************************************/
INSERT INTO t01_scrm_label_agi_CUR_I (
            scrm_label_id                           /*标签对应Id*/
           ,scrm_label_name                         /*标签名*/
           ,scrm_label_group                        /*标签分组名*/
           ,scrm_label_type                         /*标签类型*/
           ,created_tm                              /*创建时间*/
           ,updated_tm                              /*上次更新时间*/
           ,Etl_Batch_No                            /*作业批次号*/
           ,Etl_First_Dt                            /*最初入库时间*/
           ,Etl_Job                                 /*作业名称*/
           ,Etl_Proc_Dt                             /*本次入库时间*/
           ,Etl_Tx_Dt                               /*作业运行时间*/
           ,Src_Sysname                             /*来源系统*/
           ,Src_Table                               /*来源表*/
        )
SELECT
         COALESCE(TRIM(CAST(p0.id AS varchar(50))),'')             /*scrm_label_id*/
        ,COALESCE(TRIM(CAST(p0.name AS varchar(50))),'')           /*scrm_label_name*/
        ,COALESCE(TRIM(CAST(p0.group_name AS varchar(10))),'')        /*scrm_label_group*/
        ,COALESCE(TRIM(CAST(p0.type AS varchar(20))),'')           /*scrm_label_type*/
        ,COALESCE(TO_TIMESTAMP(CAST(p0.date_created AS VARCHAR(20)),'YYYY-MM-DDTHH24:mi:ssZ'),TO_TIMESTAMP(:NULLDATE,'YYYYMMDD'))        /*created_tm*/
        ,COALESCE(TO_TIMESTAMP(CAST(p0 .last_updated AS VARCHAR(20)),'YYYY-MM-DDTHH24:mi:ssZ'),TO_TIMESTAMP(:NULLDATE,'YYYYMMDD'))        /*updated_tm*/
        ,0                                                         /*Etl_Batch_No*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_First_Dt*/
        ,:ETLJOB                                                   /*Etl_Job*/
        ,current_timestamp(0)                                      /*Etl_Proc_Dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_Tx_Dt*/
        ,Substr('s98_s_scrm_tags',1,3)                             /*Src_Sysname*/
        ,'s98_s_scrm_tags'                                         /*Src_Table*/
        
FROM p10_sa.s98_s_scrm_tags  p0
;



/*将不同数据插入到临时表                                                                           */
;INSERT INTO t01_scrm_label_agi_INS (
         scrm_label_name                                           /*标签名*/
        ,scrm_label_group                                          /*标签分组名*/
        ,scrm_label_type                                           /*标签类型*/
        ,created_tm                                                /*创建时间*/
        ,updated_tm                                                /*上次更新时间*/
        ,scrm_label_id                                             /*标签对应Id*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
    SELECT
         P1.scrm_label_name                                           /*标签名*/
        ,P1.scrm_label_group                                          /*标签分组名*/
        ,P1.scrm_label_type                                           /*标签类型*/
        ,P1.created_tm                                                /*创建时间*/
        ,P1.updated_tm                                                /*上次更新时间*/
        ,P1.scrm_label_id                                             /*标签对应Id*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM t01_scrm_label_agi_CUR_I P1
LEFT JOIN :PDMDB.t01_scrm_label P2
ON    P1.scrm_label_name = P2.scrm_label_name
    AND P1.scrm_label_group = P2.scrm_label_group
    AND P1.scrm_label_type = P2.scrm_label_type
    AND P1.created_tm = P2.created_tm
    AND P1.updated_tm = P2.updated_tm
    AND P1.scrm_label_id = P2.scrm_label_id
    
WHERE  P2.scrm_label_name IS NULL
    OR P2.scrm_label_group IS NULL
    OR P2.scrm_label_type IS NULL
    OR P2.created_tm IS NULL
    OR P2.updated_tm IS NULL
    OR P2.scrm_label_id IS NULL
    
; 
/*将新增数据插入到目标表                                                                           */
;INSERT INTO :PDMDB.t01_scrm_label (
         scrm_label_name                                           /*标签名*/
        ,scrm_label_group                                          /*标签分组名*/
        ,scrm_label_type                                           /*标签类型*/
        ,created_tm                                                /*创建时间*/
        ,updated_tm                                                /*上次更新时间*/
        ,scrm_label_id                                             /*标签对应Id*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
SELECT
         P1.scrm_label_name                                           /*标签名*/
        ,P1.scrm_label_group                                          /*标签分组名*/
        ,P1.scrm_label_type                                           /*标签类型*/
        ,P1.created_tm                                                /*创建时间*/
        ,P1.updated_tm                                                /*上次更新时间*/
        ,P1.scrm_label_id                                             /*标签对应Id*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM t01_scrm_label_agi_INS P1
ON CONFLICT ( scrm_label_id)
DO UPDATE SET
     scrm_label_id=excluded.scrm_label_id
    ,scrm_label_name=excluded.scrm_label_name
    ,scrm_label_group=excluded.scrm_label_group
    ,scrm_label_type=excluded.scrm_label_type
    ,created_tm=excluded.created_tm
    ,updated_tm=excluded.updated_tm
    ,Etl_Batch_No=excluded.Etl_Batch_No
    ,Etl_First_Dt=excluded.Etl_First_Dt
    ,Etl_Job=excluded.Etl_Job
    ,Etl_Proc_Dt=excluded.Etl_Proc_Dt
    ,Etl_Tx_Dt=excluded.Etl_Tx_Dt
    ,Src_Sysname=excluded.Src_Sysname
    ,Src_Table=excluded.Src_Table
    

;
/*****程序结束退出                                               */
\q

