/***************************************************************************************************/
/*script in Sql, generate by SdmCreateScript 2020(by Qihang Feng, QF255001@TERADATA.COM)     */
/*VERSION 01.10 revised on 2020-08-25                                                              */
/*Brilliance stems from wisdoms.                                                                   */
/*************Head Section**************************************************************************/
/*Script Use: Periodically load data to :cust_leads(客户线索)             */
/*Create Date:2024-05-06 17:28:10                                                                  */
/*SDM Developed By: dev                                                                            */
/*SDM Developed Date: 2024-01-19                                                                   */
/*SDM Checked By: dev                                                                              */
/*SDM Checked Date: 2024-05-06                                                                     */
/*Script Developed By: dev                                                                         */
/*Script Checked By: dev                                                                           */
/*Source table 1: p20_pdm.t01_scrm_leads                                                           */
/*Source table 2: p20_pdm.t01_crm_raw_leads                                                        */
/*Source table 3: p20_pdm.t01_scrm_leads_his                                                       */
/*Source table 4: p20_pdm.t01_livechat_record                                                      */
/*Job Type: Inbound transform (Tier 1 to Tier 2)                                                   */
/*Target Table:cust_leads                                                                          */
/*ETL Job Name:cust_leads                                                                          */
/*ETL Frequency:Daily                                                                              */
/*ETL Policy:F1                                                                                    */
/********************************************************************************************/
/*******Main Section**************************************************************************/
\set ON_ERROR_STOP on
\set AUTOCOMMIT on
\timing on



/*创建临时表加载当前数据                                                                           */
CREATE TEMPORARY TABLE cust_leads_agi_CUR_I 
 ( LIKE :COMMDB.cust_leads)
ON COMMIT PRESERVE ROWS;


/*****************************************************************************************************/
/* GROUP 1:Source Table:t01_livechat_record***********************************************************/
/*****************************************************************************************************/
INSERT INTO cust_leads_agi_CUR_I (
            contact_channel                         /*线索渠道*/
           ,contact_account                         /*线索编号*/
           ,active_time                             /*活跃时间*/
           ,src_sysname                             /*来源系统*/
           ,src_table                               /*来源表*/
           ,etl_job                                 /*作业名称*/
           ,etl_first_dt                            /*最初入库时间*/
           ,etl_proc_dt                             /*本次入库时间*/
           ,etl_tx_dt                               /*作业运行时间*/
           ,etl_batch_no                            /*作业批次号*/
        )
SELECT
         'Livechat'                                                /*contact_channel*/
        ,COALESCE(TRIM(CAST(p0.livechat_leads_id AS VARCHAR(50))),'')        /*contact_account*/
        ,COALESCE(p0.chat_start_time,TO_TIMESTAMP(:NULLDATE,'YYYYMMDD'))        /*active_time*/
        ,Substr('t01_livechat_record',1,3)                         /*src_sysname*/
        ,'t01_livechat_record'                                     /*src_table*/
        ,:ETLJOB                                                   /*etl_job*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*etl_first_dt*/
        ,current_timestamp(0)                                      /*etl_proc_dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*etl_tx_dt*/
        ,0                                                         /*etl_batch_no*/
        
FROM p20_pdm.t01_livechat_record  p0
;



/*****************************************************************************************************/
/* GROUP 2:Source Table:t01_crm_raw_leads*************************************************************/
/*****************************************************************************************************/
INSERT INTO cust_leads_agi_CUR_I (
            contact_channel                         /*线索渠道*/
           ,contact_account                         /*线索编号*/
           ,active_time                             /*活跃时间*/
           ,src_sysname                             /*来源系统*/
           ,src_table                               /*来源表*/
           ,etl_job                                 /*作业名称*/
           ,etl_first_dt                            /*最初入库时间*/
           ,etl_proc_dt                             /*本次入库时间*/
           ,etl_tx_dt                               /*作业运行时间*/
           ,etl_batch_no                            /*作业批次号*/
        )
SELECT
         'CRM'                                                     /*contact_channel*/
        ,COALESCE(TRIM(CAST(p0.crm_contact_account AS VARCHAR(50))),'')        /*contact_account*/
        ,COALESCE(TO_TIMESTAMP(CAST(p0.create_time AS VARCHAR(19)),'YYYY-MM-DD HH24:mi:ss'),TO_TIMESTAMP(:NULLDATE,'YYYYMMDD'))        /*active_time*/
        ,Substr('t01_crm_raw_leads',1,3)                           /*src_sysname*/
        ,'t01_crm_raw_leads'                                       /*src_table*/
        ,:ETLJOB                                                   /*etl_job*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*etl_first_dt*/
        ,current_timestamp(0)                                      /*etl_proc_dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*etl_tx_dt*/
        ,0                                                         /*etl_batch_no*/
        
FROM p20_pdm.t01_crm_raw_leads  p0
;



/*****************************************************************************************************/
/* GROUP 3:Source Table:t01_scrm_leads****************************************************************/
/*****************************************************************************************************/
INSERT INTO cust_leads_agi_CUR_I (
            contact_channel                         /*线索渠道*/
           ,contact_account                         /*线索编号*/
           ,active_time                             /*活跃时间*/
           ,src_sysname                             /*来源系统*/
           ,src_table                               /*来源表*/
           ,etl_job                                 /*作业名称*/
           ,etl_first_dt                            /*最初入库时间*/
           ,etl_proc_dt                             /*本次入库时间*/
           ,etl_tx_dt                               /*作业运行时间*/
           ,etl_batch_no                            /*作业批次号*/
        )
SELECT
         'SCRM'                                                    /*contact_channel*/
        ,COALESCE(TRIM(CAST(p0.customer_id AS VARCHAR(50))),'')        /*contact_account*/
        ,COALESCE(p0.date,TO_TIMESTAMP(:NULLDATE,'YYYYMMDD'))        /*active_time*/
        ,Substr('t01_scrm_leads',1,3)                              /*src_sysname*/
        ,'t01_scrm_leads'                                          /*src_table*/
        ,:ETLJOB                                                   /*etl_job*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*etl_first_dt*/
        ,current_timestamp(0)                                      /*etl_proc_dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*etl_tx_dt*/
        ,0                                                         /*etl_batch_no*/
        
FROM p20_pdm.t01_scrm_leads  p0
;



/*****************************************************************************************************/
/* GROUP 4:Source Table:t01_scrm_leads_his************************************************************/
/*****************************************************************************************************/
INSERT INTO cust_leads_agi_CUR_I (
            contact_channel                         /*线索渠道*/
           ,contact_account                         /*线索编号*/
           ,active_time                             /*活跃时间*/
           ,src_sysname                             /*来源系统*/
           ,src_table                               /*来源表*/
           ,etl_job                                 /*作业名称*/
           ,etl_first_dt                            /*最初入库时间*/
           ,etl_proc_dt                             /*本次入库时间*/
           ,etl_tx_dt                               /*作业运行时间*/
           ,etl_batch_no                            /*作业批次号*/
        )
SELECT
         'SCRM'                                                    /*contact_channel*/
        ,COALESCE(TRIM(CAST(p0.cue_id AS VARCHAR(50))),'')         /*contact_account*/
        ,COALESCE(p0.activate_time,TO_TIMESTAMP(:NULLDATE,'YYYYMMDD'))        /*active_time*/
        ,Substr('t01_scrm_leads_his',1,3)                          /*src_sysname*/
        ,'t01_scrm_leads_his'                                      /*src_table*/
        ,:ETLJOB                                                   /*etl_job*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*etl_first_dt*/
        ,current_timestamp(0)                                      /*etl_proc_dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*etl_tx_dt*/
        ,0                                                         /*etl_batch_no*/
        
FROM p20_pdm.t01_scrm_leads_his  p0
;



/*从目标表中删除所有数据 cust_leads(客户线索)                                 */
DELETE FROM :COMMDB.cust_leads 
WHERE ETL_JOB=:ETLJOB;


/*将新增数据插入到目标表                                                                           */
;INSERT INTO :COMMDB.cust_leads (
             contact_channel                                           /*线索渠道*/
            ,contact_account                                           /*线索编号*/
            ,active_time                                               /*活跃时间*/
            ,src_sysname                                               /*来源系统*/
            ,src_table                                                 /*来源表*/
            ,etl_job                                                   /*作业名称*/
            ,etl_first_dt                                              /*最初入库时间*/
            ,etl_proc_dt                                               /*本次入库时间*/
            ,etl_tx_dt                                                 /*作业运行时间*/
            ,etl_batch_no                                              /*作业批次号*/
            
    )
    SELECT
             P1.contact_channel                                           /*线索渠道*/
            ,P1.contact_account                                           /*线索编号*/
            ,P1.active_time                                               /*活跃时间*/
            ,P1.src_sysname                                               /*来源系统*/
            ,P1.src_table                                                 /*来源表*/
            ,P1.etl_job                                                   /*作业名称*/
            ,P1.etl_first_dt                                              /*最初入库时间*/
            ,P1.etl_proc_dt                                               /*本次入库时间*/
            ,P1.etl_tx_dt                                                 /*作业运行时间*/
            ,P1.etl_batch_no                                              /*作业批次号*/
            
    FROM cust_leads_agi_CUR_I P1
 
;
/*****程序结束退出                                               */
\q

