#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.trigger_dagrun import TriggerDagRunOperator
from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_tk_cust', default_args=default_args,
schedule_interval="30 18 * * 5",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="tk_cust_failed",
    html_content='<h3>您好，tk_cust作业失败，请及时处理" </h3>')

file_Tk01 = SSHOperator(
ssh_hook=sshHook,
task_id='file_Tk01',
command='python /data/airflow/bin/FILELOD.py {{ params.my_param }} {{ ds_nodash }}  >>/data/airflow/logs/file_load/file_load_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"Tk01"},
depends_on_past=False, 
retries=3, 
dag=dag)


livechat_6381 = SSHOperator(
ssh_hook=sshHook,
task_id='livechat_6381',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_livechat"},
depends_on_past=False, 
retries=3, 
dag=dag)

file_Udesk_record = SSHOperator(
ssh_hook=sshHook,
task_id='file_Udesk_record',
command='python /data/airflow/bin/FILELOD.py {{ params.my_param }} {{ ds_nodash }}  >>/data/airflow/logs/file_load/file_load_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"Udesk_record"},
depends_on_past=False, 
retries=3, 
dag=dag)


file_CRM_Raw_Leads = SSHOperator(
ssh_hook=sshHook,
task_id='file_CRM_Raw_Leads',
command='python /data/airflow/bin/FILELOD.py {{ params.my_param }} {{ ds_nodash }}  >>/data/airflow/logs/file_load/file_load_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"CRM_Raw_Leads"},
depends_on_past=False, 
retries=3, 
dag=dag)


udesk_record_3768 = SSHOperator(
ssh_hook=sshHook,
task_id='udesk_record_3768',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_udesk_record"},
depends_on_past=False, 
retries=3, 
dag=dag)

crm_raw_leads_6024 = SSHOperator(
ssh_hook=sshHook,
task_id='crm_raw_leads_6024',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_crm_raw_leads"},
depends_on_past=False, 
retries=3, 
dag=dag)

t01_livechat_record = SSHOperator(
ssh_hook=sshHook,
task_id='t01_livechat_record',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_livechat_record_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
china_city_4536 = SSHOperator(
ssh_hook=sshHook,
task_id='china_city_4536',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_china_city"},
depends_on_past=False, 
retries=3, 
dag=dag)

country_cde_3310 = SSHOperator(
ssh_hook=sshHook,
task_id='country_cde_3310',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_country_cde"},
depends_on_past=False, 
retries=3, 
dag=dag)

file_china_city = SSHOperator(
ssh_hook=sshHook,
task_id='file_china_city',
command='python /data/airflow/bin/FILELOD.py {{ params.my_param }} {{ ds_nodash }}  >>/data/airflow/logs/file_load/file_load_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"china_city"},
depends_on_past=False, 
retries=3, 
dag=dag)


file_country_cde = SSHOperator(
ssh_hook=sshHook,
task_id='file_country_cde',
command='python /data/airflow/bin/FILELOD.py {{ params.my_param }} {{ ds_nodash }}  >>/data/airflow/logs/file_load/file_load_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"country_cde"},
depends_on_past=False, 
retries=3, 
dag=dag)


t01_crm_raw_leads = SSHOperator(
ssh_hook=sshHook,
task_id='t01_crm_raw_leads',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_crm_raw_leads_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
t00_country_info = SSHOperator(
ssh_hook=sshHook,
task_id='t00_country_info',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t00_country_info_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
t00_china_city_info = SSHOperator(
ssh_hook=sshHook,
task_id='t00_china_city_info',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t00_china_city_info_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
t01_udesk_record = SSHOperator(
ssh_hook=sshHook,
task_id='t01_udesk_record',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_udesk_record_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
d_udesk_contact = SSHOperator(
ssh_hook=sshHook,
task_id='d_udesk_contact',
command='/data/airflow/etl/COM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"d_udesk_contact_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
d_livechat_contact = SSHOperator(
ssh_hook=sshHook,
task_id='d_livechat_contact',
command='/data/airflow/etl/COM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"d_livechat_contact_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cust_contact_mapping = SSHOperator(
ssh_hook=sshHook,
task_id='cust_contact_mapping',
command='/data/airflow/etl/COM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"cust_contact_mapping_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cust_leads = SSHOperator(
ssh_hook=sshHook,
task_id='cust_leads',
command='/data/airflow/etl/COM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"cust_leads_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cust_contact_info = SSHOperator(
ssh_hook=sshHook,
task_id='cust_contact_info',
command='/data/airflow/etl/COM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"cust_contact_info_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cust_all_info = SSHOperator(
ssh_hook=sshHook,
task_id='cust_all_info',
command='/data/airflow/etl/MART/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"cust_all_info_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
data_source_update = SSHOperator(
ssh_hook=sshHook,
task_id='data_source_update',
command='/data/airflow/etl/MART/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"data_source_update_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cust_leads_detail = SSHOperator(
ssh_hook=sshHook,
task_id='cust_leads_detail',
command='/data/airflow/etl/COM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"cust_leads_detail_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cust_enagement_records = SSHOperator(
ssh_hook=sshHook,
task_id='cust_enagement_records',
command='/data/airflow/etl/MART/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"cust_enagement_records_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
file_Tk01 >> livechat_6381
file_Udesk_record >> udesk_record_3768
file_CRM_Raw_Leads >> crm_raw_leads_6024
livechat_6381 >> t01_livechat_record
file_country_cde >> country_cde_3310
file_china_city >> china_city_4536
crm_raw_leads_6024 >> t01_crm_raw_leads
country_cde_3310 >> t00_country_info
china_city_4536 >> t00_china_city_info
udesk_record_3768 >> t01_udesk_record
t01_udesk_record >> d_udesk_contact
t01_livechat_record >> d_livechat_contact
d_udesk_contact >> cust_contact_mapping
d_livechat_contact >> cust_contact_mapping
cust_contact_mapping >> cust_contact_info
cust_contact_mapping >> cust_leads
t01_crm_raw_leads >> cust_leads
cust_leads >> cust_all_info
cust_contact_info >> cust_all_info
cust_all_info >> data_source_update
cust_all_info >> cust_leads_detail
cust_leads_detail >> cust_enagement_records
cust_enagement_records >> data_source_update
data_source_update >> task_failed 
